import { Request as IttyRequest } from 'itty-router'
import { getFirstStacksBlockInRewardCycle } from "../../lib/citycoins"
import { createSingleValue, isStringAllDigits } from '../../lib/common';
import { getCityConfig } from '../../types/cities';
import { SingleValue } from '../../types/common';

const GetFirstStacksBlockInRewardCycle = async (request: IttyRequest): Promise<Response> => {
  // check inputs
  const city = request.params?.cityname ?? undefined
  const cycle = request.params?.cycleid ?? undefined
  if (city === undefined || cycle === undefined) {
    return new Response(`Invalid request, missing parameter(s)`, { status: 400 })
  }
  // get city configuration object
  const cityConfig = await getCityConfig(city)
  if (cityConfig.deployer === '') {
    return new Response(`City name not found: ${city}`, { status: 404 })
  }
  // verify target cycle is valid
  if (!isStringAllDigits(cycle)) {
    return new Response(`Target cycle not specified or invalid`, { status: 400 })
  }
  // get first stacks block in reward cycle
  const firstBlockInCycle: string = await getFirstStacksBlockInRewardCycle(cityConfig, cycle);
  if (firstBlockInCycle === null) {
    return new Response(`Reward cycle not found: ${cycle}`, { status: 404 })
  }
  // return response
  const response: SingleValue = await createSingleValue(firstBlockInCycle)
  const headers = {
    'Access-Control-Allow-Origin': '*',
    'Content-Type': 'application/json',
  }
  return new Response(JSON.stringify(response), { headers })
}

export default GetFirstStacksBlockInRewardCycle
