import { Request as IttyRequest } from 'itty-router'
import { getStackingStatsAtCycle } from "../../lib/citycoins"
import { isStringAllDigits } from '../../lib/common';
import { getCityConfig } from '../../types/cities';
import { StackingStatsAtCycle } from "../../types/stacking";

const GetStackingStatsAtCycle = async (request: IttyRequest): Promise<Response> => {
  // check inputs
  const city = request.params?.cityname ?? undefined
  const cycle = request.params?.cycleid ?? undefined
  if (city === undefined || cycle === undefined) {
    return new Response(`Invalid request, missing parameter(s)`, { status: 400 })
  }
  // get city configuration object
  const cityConfig = await getCityConfig(city)
  if (cityConfig.deployer === '') {
    return new Response(`City name not found: ${city}`, { status: 404 })
  }
  // verify target cycle is valid
  if (!isStringAllDigits(cycle)) {
    return new Response(`Target cycle not specified or invalid`, { status: 400 })
  }
  // get stacking stats at cycle
  const stackingStatsAtCycle: StackingStatsAtCycle = await getStackingStatsAtCycle(cityConfig, cycle);
  if (stackingStatsAtCycle === null) {
    return new Response(`Stacking stats not found at reward cycle: ${cycle}`, { status: 404 })
  }
  // return response
  const headers = {
    'Access-Control-Allow-Origin': '*',
    'Content-Type': 'application/json',
  }
  return new Response(JSON.stringify(stackingStatsAtCycle), { headers })
}

export default GetStackingStatsAtCycle
